@@ -15,7 +15,7 @@ rcompnorm <- function(n, m, s, type = "alr") {
   } else {
     D <- dim(x)[2]
     y <- x %*% helm(D + 1)
-    y < exp(y)
+    y <- exp(y)
   }
   y / Rfast::rowsums(y)
 }
